@@ -39,6 +39,7 @@ mod combinators;
 mod cookiepath;
 mod error;
 mod expr;
+mod filename;
 mod json;
 mod parsers;
 mod predicate;
@@ -50,4 +51,5 @@ mod sections;
 mod string;
 mod subquery;
 mod template;
+mod url;
 mod xml;
